Prints tables resulting from masking performed by brMask function to permit user to identify potential outliers by their original identities
unmask(object, obsrange=NULL, verbose=TRUE)None returned, printout only
Name of brMask object
NULL or vector of integers, NULL causes entire data frame of observation numbers to be printed
TRUE causes function identifier to display before and after run
William R. Fairweather